## Geosoup v0.1.17

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3740462.svg)](https://doi.org/10.5281/zenodo.3740462)

Geosoup is a python package for geospatial data manipulation using `GDAL` and `GDAL bindings` in python.

This package is a minimalistic software distribution for limited manipulation of common geospatial data types such as rasters, vectors and samples. All the heavy lifting is done by `GDAL`, `numpy` and, `scipy`. 

Install using:

`pip install geosoup`


_Note: Must have_ `GDAL >= 2.1.3` _up and running before installing this package._
